@@ -10,7 +10,7 @@
 /* #undef HAVE_RINT */
 #define HAVE_TIMEGM
 /* #undef HAVE_ISNAN */
-/* #undef HAVE_STD_ISNAN */
+#define HAVE_STD_ISNAN
 /* #undef HAVE_WINDOWS_H */
 #define HAVE_MKDTEMP
 
